@@ -1,9 +1,10 @@
 import os
 import pandas as pd
 from pandas.errors import EmptyDataError
-
+from datetime import date
 
 class Ptrms:
+    TODAY = date.today()
     def __init__(self, file, ref_start, ref_end, sample_start, sample_end, threshold):
         self.file = file
         self.ref_start = ref_start
@@ -70,7 +71,7 @@ class Ptrms:
         sample_window_stats = sample_window_stats.add_prefix('Sample ')
         ref_window_stats = ref_window_stats.add_prefix('Reference ')
         self.dif = pd.concat([self.dif, sample_window_stats, ref_window_stats], axis=1)
-        out_path = self.out_path(f"extracted_window.xlsx")
+        out_path = self.out_path(f"extracted_window_{self.TODAY}.xlsx")
         try:
             self.dif.to_excel(out_path)
         except PermissionError as e:
